<?php
namespace OCA\IfcViewer\AppInfo;

// use OCP\Files\IMimeTypeLoader;
// use OCP\Files\IMimeTypeDetector;
use OCP\AppFramework\App;
use OCP\Util;
use OCA\IfcViewer\AppConfig;
use OCA\IfcViewer\Controller\IfcviewerController;
use OCA\IfcViewer\Controller\SettingsController;
use OCP\AppFramework\Bootstrap\IBootContext;
use OCP\AppFramework\Bootstrap\IBootstrap;
use OCP\AppFramework\Bootstrap\IRegistrationContext;

class Application extends App implements IBootstrap
{
    private $appName = "ifcviewer";

    public function __construct()
    {
        parent::__construct($this->appName);
    }

    public function register(IRegistrationContext $context): void
    {

        $context->registerService("Logger", function ($c) {
            return $c->query("ServerContainer")
                ->getLogger();
        });

        $context->registerService("UserSession", function ($c) {
            return $c->query("ServerContainer")
                ->getUserSession();
        });

        $context->registerService("RootStorage", function ($c) {
            return $c->query("ServerContainer")
                ->getRootFolder();
        });

        $context->registerService("URLGenerator", function ($c) {
            return $c->query("ServerContainer")
                ->getURLGenerator();
        });

        $context->registerService("SettingsController", function ($c) {
            return new SettingsController($c->query("AppName"), $c->query("Request"), $c->query("Logger"));
        });

        $context->registerService("IfcviewerController", function ($c) {
            return new IfcviewerController($c->query("AppName"), $c->query("Request"), $c->query("RootStorage"), $c->query("UserSession"), $c->query("URLGenerator"), $c->query("Logger"), $c->query("IManager"), $c->query("Session"));
        });
    }

    public function boot(IBootContext $context): void
    {

        // $this->mimeTypeDetector = $mimeTypeDetector;
        // $this->mimeTypeLoader = $mimeTypeLoader;
        $eventDispatcher = \OC::$server->getEventDispatcher();
        $eventDispatcher->addListener('OCA\Files::loadAdditionalScripts', function () {
            Util::addScript('ifcviewer', 'main');
            Util::addStyle('ifcviewer', 'style');
        });

        $eventDispatcher->addListener("OCA\Files_Sharing::loadAdditionalScripts", function () {
            Util::addScript('ifcviewer', 'shareifc');
            Util::addStyle('ifcviewer', 'style');
        });

        // Register custom mimetype we can hook in the frontend
        // $this->mimeTypeDetector->getAllMappings();
        // $this->mimeTypeDetector->registerType('ifc', 'application/x-step');

        // $mimeTypeId = $this->mimeTypeLoader->getId('application/x-step');
        // $this->mimeTypeLoader->updateFilecache('ifc', $mimeTypeId);
        // $this->mimeTypeLoader->updateFilecache('%.ifc', $mimetypeId);

        // $container = $this->getContainer();

        /*
         * $container = $context->getAppContainer();
         *
         * $container->registerService("Logger", function ($c) {
         * return $c->query("ServerContainer")
         * ->getLogger();
         * });
         *
         * $container->registerService("UserSession", function ($c) {
         * return $c->query("ServerContainer")
         * ->getUserSession();
         * });
         *
         * $container->registerService("RootStorage", function ($c) {
         * return $c->query("ServerContainer")
         * ->getRootFolder();
         * });
         */
        // $manager = $context->getAppContainer()->query(IManager::class);
        // $manager->registerNotifierService(Notifier::class);
        /*
         * $container->registerService("AppConfig", function ($c) {
         *
         * });
         */

        /*
         * $container->registerService("SettingsController", function ($c) {
         * return new SettingsController($c->query("AppName"), $c->query("Request"), $c->query("Logger"), $this->appConfig);
         * });
         *
         * $container->registerService("IfcviewerController", function ($c) {
         * return new IfcviewerController($c->query("AppName"), $c->query("Request"), $c->query("RootStorage"), $c->query("UserSession"), $c->query("ServerContainer")
         * ->getURLGenerator(), $c->query("Logger"), $this->appConfig, $c->query("IManager"), $c->query("Session"));
         * });
         */
    }
}
