
(function(OCA) {

	OCA.IfcViewer = _.extend({}, OCA.IfcViewer);

	if (!OCA.IfcViewer.AppName) {
		OCA.IfcViewer = {
			AppName: "ifcviewer"
		};
	}
	
	OCA.IfcViewer.Cleanup = function(receiver, shareToken, fileId, filePath) {
		//window.removeEventListener("message", receiver);

		if (shareToken != null && shareToken != "") {
			var url = OC.generateUrl("/s/{shareToken}", {
					shareToken: shareToken
				});
				window.location.href = url;
		} else {
			var ncClient = OC.Files.getClient();
			ncClient.getFileInfo(filePath)
				.then(function(status, fileInfo) {
					var url = OC.generateUrl("/apps/files/?dir={currentDirectory}&fileid={fileId}", {
						currentDirectory: fileInfo.path,
						fileId: fileInfo.id
					});
					window.location.href = url;
				})
				.fail(function() {
					var url = OC.generateUrl("/apps/files");
					window.location.href = url;
				});
		}
	};

	OCA.IfcViewer.DisplayError = function(error) {
		$("#app")
			.text(error)
			.addClass("error");
	};


	OCA.IfcViewer.OpenFile = function(editWindow, origin, filePath) {
		console.log("Start open IFC file in bimit");

		var ncClient = OC.Files.getClient();
		var fileId = $("#iframeEditor").data("id");
		var shareToken = $("#iframeEditor").data("sharetoken");

		if (!fileId && !shareToken) {
			OCA.IfcViewer.DisplayError("FileId is empty");
			return;
		}

		var receiver = function(evt) {
			if (evt.data.length > 0 && origin.includes(evt.origin)) {
				var payload = JSON.parse(evt.data);
				if (payload.event === "init") {
					var loadMsg = OC.Notification.show("Идет загрузка, подождите...");

					ncClient.getFileContents(filePath)
						.then(function(status, contents) {
							editWindow.postMessage(contents, origin);
						})
						.fail(function(status) {
							console.log("Status Error: " + status);
							OCA.IfcViewer.Cleanup(receiver, filePath);
						})
						.done(function() {
							OC.Notification.hide(loadMsg);
						});
				}
			} else {
				console.log("Bimit error: bad origin " + evt.origin);
			}
		}
		window.addEventListener("message", receiver);
	};
	
	
	OCA.IfcViewer.CreateUrl = async function(frameUrl, projectUuid, hash, shareToken, filePath) {
		var returnUrl = "";
		var srcUrl = "";
		if (shareToken != null && shareToken != "") {
				returnUrl = OC.generateUrl("/s/{shareToken}", {
					shareToken: shareToken
				});
				srcUrl = frameUrl+ "/project/cloud/"+projectUuid+"/"+hash + "?back="+btoa(returnUrl)+"&share=1";
				
				return {"returnUrl": returnUrl, "srcUrl": srcUrl};
		} else {
			var ncClient = OC.Files.getClient();
			var urls = await ncClient.getFileInfo(filePath)
				.then(function(status, fileInfo) {
					returnUrl = OC.generateUrl("/apps/files/?dir={currentDirectory}&fileid={fileId}", {
						currentDirectory: fileInfo.path,
						fileId: fileInfo.id
					});
					srcUrl = frameUrl+ "/project/cloud/"+projectUuid+"/"+hash + "?back="+btoa(returnUrl)+"&share=0";
					return {"returnUrl": returnUrl, "srcUrl": srcUrl};
				})
				.fail(function() {
					returnUrl = OC.generateUrl("/apps/files");
					srcUrl = frameUrl+ "/project/cloud/"+projectUuid+"/"+hash + "?back="+btoa(returnUrl)+"&share=0";
					
					return {"returnUrl": returnUrl, "srcUrl": srcUrl};
				});
				
			return urls;
		}
	};

	OCA.IfcViewer.LoadFrame = async function(frameUrl, projectUuid, hash, shareToken, fileId, filePath) {

		var urls = await OCA.IfcViewer.CreateUrl(frameUrl, projectUuid, hash, shareToken, filePath);
		var srcUrl = urls["srcUrl"];
		var returnUrl = urls["returnUrl"];
		
		//var iframe = document.getElementById("iframeBimit");
		//iframe.setAttribute('returnSrc', returnUrl);
		//iframe.setAttribute('src', srcUrl);
		
		//window.open(srcUrl, '_blank');
		window.location.replace(srcUrl);
		//OCA.IfcViewer.Cleanup(null, shareToken, fileId, filePath);
	}

	OCA.IfcViewer.InitFile = function(frameUrl, filePath, shareToken, fileId, hash) {
		console.log("Start prepare IFC file to send to bimit");
		$("#iframeForm").submit(function(e) {
			e.preventDefault();
			
			var form = $("#iframeForm");
			var url = form.attr('action');
			$.ajax({
				type: "POST",
				url: url,
				data: form.serialize(), // serializes the form's elements.
				success: function(data) {
					if (data.upload == "1") {
						var loadIfc = OC.Notification.showUpdate("Загрузка, пожалуйста подожите ...");

						var dataSend = {
							relativePath: filePath,
							shareToken: shareToken,
							fileId: fileId,
							modelUuid: data.modelUuid
						};
						$.ajax({
							type: "POST",
							async: "true",
							url: OC.generateUrl("apps/" + OCA.IfcViewer.AppName + "/ajax/send"),
							data: dataSend,
							success: function(element) {

								OC.Notification.hide(loadIfc);

								response = JSON.parse(element);
								if (response.httpCode == 1) {
									OC.Notification.show("Загрузка завершена", { timeout: 10000 });
									OCA.IfcViewer.LoadFrame(frameUrl, data.uuid, hash);
								} else {
									//bimitWindow.close();
									
									OC.dialogs.info(
										t('ifcviewer', response.error_description),
										"Ошибка", function() { OCA.IfcViewer.Cleanup(null, shareToken, fileId, filePath) }, true
									);

								}
							}
						});


						//OC.dialogs.info("Загрузка, пожалуйста подожите ...", "Загрузка", null, true);
						//OC.Notification.show("Загрузка, пожалуйста подожите ...", {timeout: 10000});

					} else {
						OCA.IfcViewer.LoadFrame(frameUrl, data.uuid, hash, shareToken, fileId, filePath);
					}
				},
				error: function(data) {
					//bimitWindow.close();
					
					var message = "Ошибка открытия файла";
					if (data.responseText) {
						var jsData = JSON.parse(data.responseText);
						message = jsData.error_description ? jsData.error_description : "Ошибка открытия файла";
					}
					
					OC.dialogs.info(
						t('ifcviewer', message),
						"Ошибка", function() { OCA.IfcViewer.Cleanup(null, shareToken, fileId, filePath) }, true
					);
					//OCA.IfcViewer.Cleanup(null, filePath);
					//OCA.IfcViewer.DisplayError(message);
					//OC.Notification.showUpdate(message, { type: "error", timeout: 20000 });
				}
			});

		});

		$("#iframeForm").submit();
	};



})(OCA);
