<?php
namespace OCA\IfcViewer\Controller;

use OCP\AppFramework\Controller;
use OCP\AppFramework\Http\TemplateResponse;
use OCP\ILogger;
use OCP\IRequest;
use OCA\IfcViewer\AppConfig;
use OCA\IfcViewer\Migration;

class SettingsController extends Controller
{

    private $logger;

    private $config;

    /**
     *
     * @param string $AppName
     *            - application name
     * @param IRequest $request
     *            - request object
     * @param IL10N $trans
     *            - l10n service
     * @param ILogger $logger
     *            - logger
     * @param OCA\Bimit\AppConfig $config
     *            - application configuration
     */
    public function __construct($AppName, IRequest $request, ILogger $logger, \OCA\IfcViewer\AppConfig $config)
    {
        parent::__construct($AppName, $request);

        $this->logger = $logger;
        $this->config = new AppConfig($AppName);
    }

    /**
     * Config page
     *
     * @return TemplateResponse
     */
    public function index()
    {
        $data = [
            "bimitUrl" => $this->config->GetBimitUrl()
        ];
        return new TemplateResponse($this->appName, "settings", $data, "blank");
    }

    public function settings()
    {
        $bimit = trim($_POST['bimitUrl']);
        $this->config->SetBimitUrl($bimit);

        if (version_compare(implode(".", \OCP\Util::getVersion()), "13", ">=")) {
            $checkmime = new \OCA\IfcViewer\Migration\CheckMimeType();
            $registered = $checkmime->run();

            if ($registered == false) {
                $mimeTypeLoader = \OC::$server->getMimeTypeLoader();
                $mime = new \OCA\IfcViewer\Migration\RegisterMimeType($mimeTypeLoader);
                $output = new \OC\Migration\SimpleOutput($this->logger, $this->appName);
                $mime->run($output);
            }
        }

        return [
            "bimitUrl" => $this->config->GetBimitUrl()
        ];
    }

    /**
     * Get supported formats
     *
     * @return array
     *
     * @NoAdminRequired
     * @PublicPage
     * @NoCSRFRequired
     */
    public function getsettings()
    {
        $data = array();
        $data['formats'] = $this->config->formats;
        $data['settings'] = array();
        $data['settings']['bimitUrl'] = $this->config->GetBimitUrl();
        return $data;
    }
}
